==> haskell-postgresql-simple-0.6.5-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-simple
version:              0.6.5
visibility:           public
id:                   postgresql-simple-0.6.5-I2Rn9VdOHQtGVEo2sjKHmK
key:                  postgresql-simple-0.6.5-I2Rn9VdOHQtGVEo2sjKHmK
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  88f3964106c7c9af46189ebc089cc186
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/postgresql-simple-0.6.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/postgresql-simple-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5-I2Rn9VdOHQtGVEo2sjKHmK
depends:
    Only-0.1-DiaFlOQSZ1l8JCg8TmCabZ
    aeson-2.1.2.1-7IgTEIjsesxDBKStPrg8Ee
    attoparsec-0.14.4-Gy8NthJdplC7rvqKUZX715 base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-AaasGaU67AZI2uOcvgi7uv
    containers-0.6.5.1 hashable-1.4.4.0-3NsDO7W5NBvlxFY7M8nbj
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    scientific-0.3.7.0-CRm8E7lQFQyIDH2IUurUTy template-haskell-2.18.0.0
    text-1.2.5.0 time-compat-1.9.6.1-HJyqc1lWxZa5eQw9SNx394
    transformers-0.5.6.2 uuid-types-1.0.5.1-Aqvu4kBmUOkGNStXR8PuIb
    vector-0.13.1.0-7kspXIhsfaQEZQW3lsFmcE

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-simple-0.6.5-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-simple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-simple
version:              0.6.5
visibility:           public
id:                   postgresql-simple-0.6.5-JwF7Z9A6NAxGmWQDrpcDdO
key:                  postgresql-simple-0.6.5-JwF7Z9A6NAxGmWQDrpcDdO
license:              BSD-3-Clause
copyright:
    (c) 2011 MailRank, Inc.
    (c) 2011-2018 Leon P Smith
    (c) 2018-2020 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Bryan O'\''Sullivan, Leon P Smith
synopsis:             Mid-Level PostgreSQL client library
description:
    Mid-Level PostgreSQL client library, forked from mysql-simple.

category:             Database
abi:                  73a964ad9ebee18e074b9fb2252f01ab
exposed:              True
exposed-modules:
    Database.PostgreSQL.Simple Database.PostgreSQL.Simple.Arrays
    Database.PostgreSQL.Simple.Copy Database.PostgreSQL.Simple.Cursor
    Database.PostgreSQL.Simple.Errors
    Database.PostgreSQL.Simple.FromField
    Database.PostgreSQL.Simple.FromRow
    Database.PostgreSQL.Simple.HStore
    Database.PostgreSQL.Simple.HStore.Internal
    Database.PostgreSQL.Simple.Internal
    Database.PostgreSQL.Simple.LargeObjects
    Database.PostgreSQL.Simple.Newtypes
    Database.PostgreSQL.Simple.Notification
    Database.PostgreSQL.Simple.Ok Database.PostgreSQL.Simple.Range
    Database.PostgreSQL.Simple.SqlQQ Database.PostgreSQL.Simple.Time
    Database.PostgreSQL.Simple.Time.Internal
    Database.PostgreSQL.Simple.ToField Database.PostgreSQL.Simple.ToRow
    Database.PostgreSQL.Simple.Transaction
    Database.PostgreSQL.Simple.TypeInfo
    Database.PostgreSQL.Simple.TypeInfo.Macro
    Database.PostgreSQL.Simple.TypeInfo.Static
    Database.PostgreSQL.Simple.Types Database.PostgreSQL.Simple.Vector
    Database.PostgreSQL.Simple.Vector.Unboxed

hidden-modules:
    Database.PostgreSQL.Simple.Compat
    Database.PostgreSQL.Simple.HStore.Implementation
    Database.PostgreSQL.Simple.Internal.PQResultUtils
    Database.PostgreSQL.Simple.Time.Implementation
    Database.PostgreSQL.Simple.Time.Internal.Parser
    Database.PostgreSQL.Simple.Time.Internal.Printer
    Database.PostgreSQL.Simple.TypeInfo.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/postgresql-simple-0.6.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/postgresql-simple-0.6.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-postgresql-simple
hs-libraries:         HSpostgresql-simple-0.6.5-JwF7Z9A6NAxGmWQDrpcDdO
depends:
    Only-0.1-DiaFlOQSZ1l8JCg8TmCabZ
    aeson-2.1.2.1-HbpdIbO6AMR9AnrzgnqgHA
    attoparsec-0.14.4-41Mp0Rehn85G1bRN4BaFh7 base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-JUM6fESZLXwGrFMGnpRYl
    containers-0.6.5.1 hashable-1.4.4.0-BiMdM8DAZvpBwJziK8reqF
    postgresql-libpq-0.9.4.3-KEIdZq7PBXuLHl7WTAWu9q
    scientific-0.3.7.0-FF6Yj1fy4Cu6vTh2CP6znD template-haskell-2.18.0.0
    text-1.2.5.0 time-compat-1.9.6.1-DVj0HJcm2EeCvNiK3HVXvP
    transformers-0.5.6.2 uuid-types-1.0.5.1-3vDxVg0JZxj7miCGNAYkQm
    vector-0.13.1.0-L0sJ9rsFoTeKCVYCfA24Gj

haddock-interfaces:
    /usr/share/doc/haskell-postgresql-simple/html/postgresql-simple.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-simple/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
